==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/record/vo/RecordContrastanalysistVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 对比分析变更记录表
 * 
 * @author generator
 * 
 */
public class RecordContrastanalysistVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long contrastanalysisId; // 对比分析id
    private java.lang.String contrastanalysisCode; // 对比分析变更记录编码
    private java.lang.String billCode; // 单据编码
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long agentId; // 经办人id
    private java.lang.String agentName; // 经办人名称
    private java.math.BigDecimal tenderTotal; // 投标阶段合计
    private java.math.BigDecimal quotaTotal; // 限额设计阶段合计
    private java.math.BigDecimal budgetEstimateTotal; // 设计概算阶段合计
    private java.math.BigDecimal constructionTotal; // 施工图预算阶段合计
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.util.Date effectTime; // 生效时间
    private java.lang.String changeReason; // 变更原因
    
    private List<RecordContrastanalysisdetailVO> contrastanalysisdetailEntities = new ArrayList<>(); // 对比分析变更记录子表

    /**
     * 对比分析id
     */
    public Long getContrastanalysisId() {
        return contrastanalysisId;
    }

    /**
     * 对比分析id
     */
    public void setContrastanalysisId(Long contrastanalysisId) {
        this.contrastanalysisId = contrastanalysisId;
    }

    /**
     * 对比分析变更记录编码
     */
    public String getContrastanalysisCode() {
        return contrastanalysisCode;
    }

    /**
     * 对比分析变更记录编码
     */
    public void setContrastanalysisCode(String contrastanalysisCode) {
        this.contrastanalysisCode = contrastanalysisCode;
    }

    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 投标阶段合计
     */
    public java.math.BigDecimal getTenderTotal() {
        return tenderTotal;
    }

    /**
     * 投标阶段合计
     */
    public void setTenderTotal(java.math.BigDecimal tenderTotal) {
        this.tenderTotal = tenderTotal;
    }
    /**
     * 限额设计阶段合计
     */
    public java.math.BigDecimal getQuotaTotal() {
        return quotaTotal;
    }

    /**
     * 限额设计阶段合计
     */
    public void setQuotaTotal(java.math.BigDecimal quotaTotal) {
        this.quotaTotal = quotaTotal;
    }
    /**
     * 设计概算阶段合计
     */
    public java.math.BigDecimal getBudgetEstimateTotal() {
        return budgetEstimateTotal;
    }

    /**
     * 设计概算阶段合计
     */
    public void setBudgetEstimateTotal(java.math.BigDecimal budgetEstimateTotal) {
        this.budgetEstimateTotal = budgetEstimateTotal;
    }
    /**
     * 施工图预算阶段合计
     */
    public java.math.BigDecimal getConstructionTotal() {
        return constructionTotal;
    }

    /**
     * 施工图预算阶段合计
     */
    public void setConstructionTotal(java.math.BigDecimal constructionTotal) {
        this.constructionTotal = constructionTotal;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectTime() {
        return effectTime;
    }

    /**
     * 生效时间
     */
    public void setEffectTime(java.util.Date effectTime) {
        this.effectTime = effectTime;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    
     /**
      * 对比分析变更记录子表
      */
    public List<RecordContrastanalysisdetailVO> getContrastanalysisdetailEntities() {
        return contrastanalysisdetailEntities;
    }

    /**
     * 对比分析变更记录子表
     */
    public void setContrastanalysisdetailEntities(List<RecordContrastanalysisdetailVO> contrastanalysisdetailEntities) {
        this.contrastanalysisdetailEntities = contrastanalysisdetailEntities;
    }


}

==> ejc-budgetmanage-impl-3.0.0-20230324.091733-161-sources.jar: com/ejianc/business/record/vo/RecordContrastanalysistVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 对比分析变更记录表
 * 
 * @author generator
 * 
 */
public class RecordContrastanalysistVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long contrastanalysisId; // 对比分析id
    private java.lang.String contrastanalysisCode; // 对比分析变更记录编码
    private java.lang.String billCode; // 单据编码
    private java.lang.Long projectId; // 项目id
    private java.lang.Long quotasummaryId; // 限额设计汇总id
    private java.lang.Long designestimateId; // 设计概算id
    private java.lang.Long consdrawbudgetTotalId; // 施工图预算汇总id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long agentId; // 经办人id
    private java.lang.String agentName; // 经办人名称
    private java.math.BigDecimal tenderTotal; // 投标阶段合计
    private java.math.BigDecimal quotaTotal; // 限额设计阶段合计
    private java.math.BigDecimal budgetEstimateTotal; // 设计概算阶段合计
    private java.math.BigDecimal constructionTotal; // 施工图预算阶段合计
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.util.Date effectTime; // 生效时间
    private java.lang.String changeReason; // 变更原因
    
    private List<RecordContrastanalysisdetailVO> contrastanalysisdetailEntities = new ArrayList<>(); // 对比分析变更记录子表

    /**
     * 对比分析id
     */
    public Long getContrastanalysisId() {
        return contrastanalysisId;
    }

    /**
     * 对比分析id
     */
    public void setContrastanalysisId(Long contrastanalysisId) {
        this.contrastanalysisId = contrastanalysisId;
    }

    /**
     * 对比分析变更记录编码
     */
    public String getContrastanalysisCode() {
        return contrastanalysisCode;
    }

    /**
     * 对比分析变更记录编码
     */
    public void setContrastanalysisCode(String contrastanalysisCode) {
        this.contrastanalysisCode = contrastanalysisCode;
    }

    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 投标阶段合计
     */
    public java.math.BigDecimal getTenderTotal() {
        return tenderTotal;
    }

    /**
     * 投标阶段合计
     */
    public void setTenderTotal(java.math.BigDecimal tenderTotal) {
        this.tenderTotal = tenderTotal;
    }
    /**
     * 限额设计阶段合计
     */
    public java.math.BigDecimal getQuotaTotal() {
        return quotaTotal;
    }

    /**
     * 限额设计阶段合计
     */
    public void setQuotaTotal(java.math.BigDecimal quotaTotal) {
        this.quotaTotal = quotaTotal;
    }
    /**
     * 设计概算阶段合计
     */
    public java.math.BigDecimal getBudgetEstimateTotal() {
        return budgetEstimateTotal;
    }

    /**
     * 设计概算阶段合计
     */
    public void setBudgetEstimateTotal(java.math.BigDecimal budgetEstimateTotal) {
        this.budgetEstimateTotal = budgetEstimateTotal;
    }
    /**
     * 施工图预算阶段合计
     */
    public java.math.BigDecimal getConstructionTotal() {
        return constructionTotal;
    }

    /**
     * 施工图预算阶段合计
     */
    public void setConstructionTotal(java.math.BigDecimal constructionTotal) {
        this.constructionTotal = constructionTotal;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectTime() {
        return effectTime;
    }

    /**
     * 生效时间
     */
    public void setEffectTime(java.util.Date effectTime) {
        this.effectTime = effectTime;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    
     /**
      * 对比分析变更记录子表
      */
    public List<RecordContrastanalysisdetailVO> getContrastanalysisdetailEntities() {
        return contrastanalysisdetailEntities;
    }

    /**
     * 对比分析变更记录子表
     */
    public void setContrastanalysisdetailEntities(List<RecordContrastanalysisdetailVO> contrastanalysisdetailEntities) {
        this.contrastanalysisdetailEntities = contrastanalysisdetailEntities;
    }

    public Long getQuotasummaryId() {
        return quotasummaryId;
    }

    public void setQuotasummaryId(Long quotasummaryId) {
        this.quotasummaryId = quotasummaryId;
    }

    public Long getDesignestimateId() {
        return designestimateId;
    }

    public void setDesignestimateId(Long designestimateId) {
        this.designestimateId = designestimateId;
    }

    public Long getConsdrawbudgetTotalId() {
        return consdrawbudgetTotalId;
    }

    public void setConsdrawbudgetTotalId(Long consdrawbudgetTotalId) {
        this.consdrawbudgetTotalId = consdrawbudgetTotalId;
    }
}
